@@ -5,8 +5,8 @@ from os.path import join
 import xdg.BaseDirectory
 from configobj import ConfigObj
 from configobj import flatten_errors
-from validate import Validator
-from validate import VdtValueError
+from configobj.validate import Validator
+from configobj.validate import VdtValueError
 
 from todoman import __documentation__
 
@@ -30,7 +30,10 @@ def validate_cache_path(path):
     if path:
         return expand_path(path)
     else:
-        return os.path.join(xdg.BaseDirectory.xdg_cache_home, "todoman/cache.sqlite3",)
+        return os.path.join(
+            xdg.BaseDirectory.xdg_cache_home,
+            "todoman/cache.sqlite3",
+        )
 
 
 def validate_date_format(fmt):
